+++
title = "Tuned Mass Damper"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
: [Passive Damping]({{< relref "passive_damping.md" >}}), [Mass Spring Damper Systems]({{< relref "mass_spring_damper_systems.md" >}})

Review: <elias17_resear_devel_vibrat_contr_struc>, <&verbaan15_robus>


## Working Principle {#working-principle}

The basic idea is to damp the resonance of a structure (called the primary system) by attaching a resonant system to it, the Tuned Mass Damper (TMD).
Usually, the resonance frequency of the TMD should match the resonance of the primary system that is to be damped.
The TMD then has large internal damping such that the energy is dissipated (i.e. the resonance of the primary system is well damped).

Below is a lecture about tuned mass damper.

{{< youtube qDzGCgLu59A >}}

And a simple experiment showing how a tuned mass damper works with a vibration cantilever beam.

{{< youtube HDa1VO1VDpc >}}


## How to properly apply a TMD? {#how-to-properly-apply-a-tmd}

Few questions:

-   What damping mechanism to use?
    Eddy current damping?
    Viscous damping?
-   How to optimize parameters of the TMD (i.e. mass, stiffness and damping)?
-   Where to fix the TMD to the structure?


## Tuned Mass Damper Optimization {#tuned-mass-damper-optimization}

The optimal parameters of the tuned mass damper can be roughly estimated as follows:

-   Choose the maximum acceptable mass of the TMD \\(m\_2\\) and note:
    \\[ \mu = m\_2/m\_1 \\]
    where \\(m\_1\\) is the mass of the system to damp
-   The resonance frequency of the tuned mass damper should be chosen to be
    \\[ \nu = \frac{1}{1 + \mu} \approx 1 \\]
    As usually we have \\(\mu \ll 1\\) (i.e. TMD mass small compared to the structure mass, for instance few percent)
-   This allows to compute the stiffness of the TMD:
    \\[ k\_2 = \nu^2 k\_1 \mu = k\_1 \frac{\mu}{(1 + \mu)^2} \\]
-   Finally, the optimal damping of the TMD is:
    \\[ \xi\_2 = \sqrt{\frac{3 \mu}{8 (1 + \mu)}} \Longrightarrow c\_2 = 2 \xi\_2 \sqrt{k\_2 m\_2} \\]


## Simple TMD model {#simple-tmd-model}


### Model {#model}

Let's consider a primary system that is represented by a [Mass Spring Damper Systems]({{< relref "mass_spring_damper_systems.md" >}}) with the following parameters: \\(m\_1\\), \\(k\_1\\), \\(c\_1\\).
The TMD is also represented by a mass-spring-damper system with parameters \\(m\_2\\), \\(k\_2\\), \\(c\_2\\).
The system is schematically represented in Figure [1](#figure--fig:tuned-mass-damper-schematic).

The goal is to limit the peak amplitude of \\(x\_1\\) due to \\(x\_0\\) (or a force affecting \\(m\_1\\) for instance).

<a id="figure--fig:tuned-mass-damper-schematic"></a>

{{< figure src="/ox-hugo/tuned_mass_damper_schematic.png" caption="<span class=\"figure-number\">Figure 1: </span>Mass Spring Damper representation of the Primary System and the Tuned Mass Damper" >}}

The parameter of the primary system are defined as follow:

```matlab
%% Primary system parameters
m1 = 100; % Mass [kg]
k1 = 1e7; % Stiffness [N/m]
c1 = 300; % Damping [N/(m/s)]
```

Then, the mass of the TMD is fixed and its optical parameters are computed:

```matlab
%% Tuned Mass Damper Parameters
mu = 0.02; % Mass ratio

m2 = mu*m1;
k2 = k1*mu/(1 + mu)^2;
xi = sqrt(3*mu/(8*(1 + mu)));
c2 = 2*xi*sqrt(k2*m2);
```

<div class="table-caption">
  <span class="table-number">Table 1:</span>
  Obtained parameters of the TMD
</div>

|       | Mass `m2` [kg] | Stiffness `k2` [N/m] | Damping `c2` [N/(m/s)] |
|-------|----------------|----------------------|------------------------|
| Value | 2              | 192234               | 106.338                |

The transfer function from \\(x\_0\\) to \\(x\_1\\) with and without the TMD are computed and shown in Figure

```matlab
%% Transfer function from X0 to X1 without TMD
G1 = (c1*s + k1)/(m1*s^2 + c1*s + k1);

%% Transfer function from X0 to X1 with TMD
G2 = (m2*s^2 + c2*s + k2)*(c1*s + k1)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
```

<a id="figure--fig:tuned-mass-damper-effect-tmd"></a>

{{< figure src="/ox-hugo/tuned_mass_damper_effect_tmd.png" caption="<span class=\"figure-number\">Figure 2: </span>Comparison of the transmissibility with and without the TMD" >}}

Let's now see how the mass of the TMD can affect its efficiency.

The following mass ratios are tested:

```matlab
%% Mass ratios
mus = [0.01, 0.02, 0.05, 0.1];
```

The obtained transfer functions are shown in Figure [3](#figure--fig:tuned-mass-damper-mass-effect).

<a id="figure--fig:tuned-mass-damper-mass-effect"></a>

{{< figure src="/ox-hugo/tuned_mass_damper_mass_effect.png" caption="<span class=\"figure-number\">Figure 3: </span>Effect of the TMD mass on its efficiency" >}}

The maximum amplification (i.e. \\(\mathcal{H}\_\infty\\) norm) of the transmissibility as a function of the mass ratio is shown in Figure [4](#figure--fig:tuned-mass-damper-effect-mass-ratio).
This relation can help to determine the minimum mass of the TMD that will give acceptable results.

<a id="figure--fig:tuned-mass-damper-effect-mass-ratio"></a>

{{< figure src="/ox-hugo/tuned_mass_damper_effect_mass_ratio.png" caption="<span class=\"figure-number\">Figure 4: </span>Maximum amplification due to resonance as a function of the mass ratio" >}}


## Manufacturers {#manufacturers}

-   <https://vibratec.se/en/product/high-frequency-tuned-mass-damper/>
-   <https://micromega-dynamics.com/products/vibration-control/passive-damping-devices/>
-   <https://www.csaengineering.com/products-services/tuned-dampers-absorbers.html>


## Ways to add damping {#ways-to-add-damping}

Possible damping sources:

-   Magnetic ([Eddy Current Damping]({{< relref "eddy_current_damping.md" >}}))
-   Viscous fluid
-   Elastomer ([example](https://www.dspe.nl/knowledge/dppm-cases/tuned-mass-damper-with-damped-mass-far-away-from-point-of-interest/))

| Fuild                | Reference          |
|----------------------|--------------------|
| Rocol Kilopoise 0868 | <&verbaan15_robus> |


## Review of existing TMD {#review-of-existing-tmd}

{{< figure src="/ox-hugo/tmd_ligo.png" caption="<span class=\"figure-number\">Figure 5: </span>Tuned Mass Damper used at LIGO" >}}

{{< figure src="/ox-hugo/tmd_smac.jpg" caption="<span class=\"figure-number\">Figure 6: </span>Commercial product from [SMAC](https://smac-sas.com/en/tuned-mass-damper/)" >}}

<./biblio/references.bib>
